<?php
/**
 * @version     $Id$
 * @package     Jumbotron
 * @subpackage  com_jumbotron
 * @copyright   Copyright 2010 - 2011 Jumbotron Sports. All rights reserved.
 * @license     GNU General Public License version 2 or later.
 */

// No direct access
defined('_JEXEC') or die;

jimport('joomla.application.component.view');

/**
 * Jumbotron view.
 *
 * @package     Jumbotron
 * @subpackage  com_jumbotron
 * @since       2.7.0
 */
class JumbotronViewConference extends JView
{
	/**
	 * @var    JObject	The data for the record being displayed.
	 * @since  2.7.0
	 */
	protected $item;

	/**
	 * @var    JForm  The form object for this record.
	 * @since  2.7.0
	 */
	protected $form;

	/**
	 * @var    JObject  The model state.
	 * @since  2.7.0
	 */
	protected $state;

	/**
	 * Prepare and display the Conference view.
	 *
	 * @return  void
	 * @since   2.7.0
	 */
	public function display()
	{
		// Intialiase variables.
		$this->item		= $this->get('Item');
		$this->form		= $this->get('Form');
		$this->state	= $this->get('State');

		// Check for errors.
		if (count($errors = $this->get('Errors'))) {
			JError::raiseError(500, implode("\n", $errors));
			return false;
		}

		$this->addToolbar();
		parent::display();
	}

	/**
	 * Add the page title and toolbar.
	 *
	 * @return  void
	 * @since   2.7.0
	 */
	protected function addToolbar()
	{
		JRequest::setVar('hidemainmenu', true);

		$user		= JFactory::getUser();
		$isNew		= ($this->item->id == 0);
		$checkedOut	= !($this->item->checked_out == 0 || $this->item->checked_out == $user->get('id'));
		$canDo		= JumbotronHelper::getActions();

		JToolBarHelper::title(
			JText::_(
				'COM_JUMBOTRON_'.
				($checkedOut
					? 'VIEW_CONFERENCE'
					: ($isNew ? 'ADD_CONFERENCE' : 'EDIT_CONFERENCE')).'_TITLE'
			), 'jumbotron'
		);

		// If not checked out, can save the item.
		if (!$checkedOut && $canDo->get('core.edit')) {
			JToolBarHelper::apply('Conference.apply', 'JTOOLBAR_APPLY');
			JToolBarHelper::save('Conference.save', 'JTOOLBAR_SAVE');
			JToolBarHelper::custom('Conference.save2new', 'save-new.png', null, 'JTOOLBAR_SAVE_AND_NEW', false);
		}

		// If an existing item, can save to a copy.
		if (!$isNew && $canDo->get('core.create')) {
			JToolBarHelper::custom('Conference.save2copy', 'save-copy.png', null, 'JTOOLBAR_SAVE_AS_COPY', false);
		}

		if (empty($this->item->id))  {
			JToolBarHelper::cancel('Conference.cancel', 'JTOOLBAR_CANCEL');
		}
		else {
			JToolBarHelper::cancel('Conference.cancel', 'JTOOLBAR_CLOSE');
		}
	}
}